package com.takensoft.ai_lms.common.filter;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.takensoft.ai_lms.common.confing.CommonConfig;
import com.takensoft.ai_lms.common.util.JwtUtil;
import com.takensoft.ai_lms.lms.auth.vo.UserVO;
import jakarta.servlet.FilterChain;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.web.authentication.UsernamePasswordAuthenticationFilter;


import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class LoginFilter extends UsernamePasswordAuthenticationFilter{

    private final AuthenticationManager authenticationManager;
    private final JwtUtil jwtUtil;
    private final CommonConfig commonConfig;

    private static long JWT_ACCESSTIME; // access 토큰 유지 시간

    public LoginFilter(AuthenticationManager authenticationManager, JwtUtil jwtUtil, CommonConfig commonConfig, @Value("${spring.jwt.accessTime}") long jwtAccesstime) {
        this.authenticationManager = authenticationManager;
        this.jwtUtil = jwtUtil;
        this.commonConfig = commonConfig;

        this.JWT_ACCESSTIME = jwtAccesstime;

        setFilterProcessesUrl("/auth/login.json");
    }

    /**
     * 로그인 검증
     */
    @Override
    public Authentication attemptAuthentication(HttpServletRequest request, HttpServletResponse response) throws AuthenticationException {
        try {
            Map<String, String> loginData = new ObjectMapper().readValue(request.getInputStream(), Map.class);
            String loginId = loginData.get("loginId");
            String password = loginData.get("password");

            UsernamePasswordAuthenticationToken authToken = new UsernamePasswordAuthenticationToken(loginId, password);
            return authenticationManager.authenticate(authToken);
        } catch (IOException e) {
            throw new RuntimeException("Failed to parse authentication request body", e);
        }
    }

    // 인증 성공 시
    @Override
    protected void successfulAuthentication(HttpServletRequest request, HttpServletResponse response, FilterChain chain, Authentication authResult) throws IOException {
        response.setStatus(HttpServletResponse.SC_OK);
        response.setContentType("application/json;charset=UTF-8");

        UserVO user = (UserVO) authResult.getPrincipal();
        String usid = user.getUsid();
        String loginId = user.getUsername();
        String userNm = user.getUserNm();
        List<String> author = (List) user.getAuthorities();

        String accessToken = jwtUtil.createJwt("Authorization", usid, loginId, userNm, author, JWT_ACCESSTIME);

        Map<String, Object> resData = new HashMap<>();
        resData.put("result", "success");
        resData.put("message", "로그인 성공");

        // 헤더 방식
        response.setHeader("Authorization", accessToken);

        response.getWriter().write(new ObjectMapper().writeValueAsString(resData));
    }

    // 인증 실패 시
    @Override
    protected void unsuccessfulAuthentication(HttpServletRequest request, HttpServletResponse response, AuthenticationException failed) throws IOException {
        response.setStatus(HttpServletResponse.SC_UNAUTHORIZED);
        response.setContentType("application/json;charset=UTF-8");

        Map<String, String> responseData = new HashMap<>();
        responseData.put("message", "Authentication failed: " + failed.getMessage());

        response.setContentType(MediaType.APPLICATION_JSON_VALUE);
        response.setStatus(HttpStatus.UNAUTHORIZED.value());
        response.getWriter().write(commonConfig.getObjectMapper().writeValueAsString(responseData));
    }
}
