package com.takensoft.ai_lms.common.util;

import com.takensoft.ai_lms.lms.auth.vo.UserAuthorVO;
import com.takensoft.ai_lms.lms.auth.vo.UserVO;
import io.jsonwebtoken.Claims;
import io.jsonwebtoken.Jwts;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.stereotype.Component;

import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.util.*;

@Component
public class JwtUtil {

    private SecretKey secretKey;

    public JwtUtil(@Value("${spring.jwt.secret}") String secret) {
        this.secretKey = new SecretKeySpec(secret.getBytes(StandardCharsets.UTF_8), Jwts.SIG.HS256.key().build().getAlgorithm());
    }

    // 토큰 생성 메서드
    public String createJwt(String category, String usid, String loginId, String userNm, List<String> author, long expiredMs) {

        return Jwts.builder()
                .claim("category", category)
                .claim("usid", usid)
                .claim("loginId", loginId)
                .claim("userNm", userNm)
                .claim("author", author)
                .issuedAt(new Date(System.currentTimeMillis()))
                .expiration(new Date(System.currentTimeMillis() + expiredMs))
                .signWith(secretKey)
                .compact();
    }
    public String getCategory(String token) {
        return Jwts.parser().verifyWith(secretKey).build().parseSignedClaims(token).getPayload().get("category", String.class);
    }

    // 아이디 반환 메서드
    public String getUsid(String token) {
        return Jwts.parser().verifyWith(secretKey).build().parseSignedClaims(token).getPayload().get("usid", String.class);
    }
    // 사용자 아이디 반환 메서드
    public String getLoginId(String token) {
        return Jwts.parser().verifyWith(secretKey).build().parseSignedClaims(token).getPayload().get("loginId", String.class);
    }
    // 사용자 이름 반환 메서드
    public String getUserNm(String token) {
        return Jwts.parser().verifyWith(secretKey).build().parseSignedClaims(token).getPayload().get("userNm", String.class);
    }
    // 접속자 토큰 기반 권한정보 추출
    public List<UserAuthorVO> getRoles(String token) {
        // 토큰에서 권한 정보를 가져옴
        Claims claims = Jwts.parser().verifyWith(secretKey).build().parseSignedClaims(token).getPayload();
        List<HashMap> roles = claims.get("author", List.class);
        List<UserAuthorVO> authorList = new ArrayList<>();
        if (roles != null && !roles.isEmpty()) {
            for(Map role : roles) {
                UserAuthorVO mberAuthor = new UserAuthorVO();
                mberAuthor.setAuthorCode(role.get("authority").toString());
                authorList.add(mberAuthor);
            }
        }
        System.out.println("authorList : " + authorList);
        return authorList;
    }

    // 토큰 소멸 여부
    public Boolean isExpired(String token) {
        return Jwts.parser().verifyWith(secretKey).build().parseSignedClaims(token).getPayload().getExpiration().before(new Date());
    }

    // 로그인 사용자 아이디 조회
    public String getWriter() {
        String loginId = null;
        Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
        if(authentication != null && authentication.isAuthenticated()) {
            Object principal = authentication.getPrincipal();
            if(principal instanceof UserDetails) loginId = ((UserVO) authentication.getPrincipal()).getLoginId();
        }
        return loginId;
    }

}
