package com.takensoft.ai_lms.lms.auth.service.Impl;

import com.takensoft.ai_lms.common.idgen.service.IdgenService;
import com.takensoft.ai_lms.common.util.JwtUtil;
import com.takensoft.ai_lms.lms.auth.dao.AuthDAO;
import com.takensoft.ai_lms.lms.auth.service.AuthService;
import com.takensoft.ai_lms.lms.auth.vo.UserVO;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.HashMap;
import java.util.Map;

/**
 * @author  : 방선주
 * @since   : 2024.07.12
 * 사용자 관련 구현체
 * EgovAbstractServiceImpl : 전자정부 상속
 * AuthService : 인중 인터페이스 상속
 */
@Service("authService")
@RequiredArgsConstructor
public class AuthServiceImpl extends EgovAbstractServiceImpl implements UserDetailsService, AuthService {

    private final AuthDAO authDAO;
    private final BCryptPasswordEncoder bCryptPasswordEncoder;
    private final JwtUtil jwtUtil;

    private final IdgenService userIdgn;

    @Override
    @Transactional(readOnly = true)
    public UserDetails loadUserByUsername(String loginId) throws UsernameNotFoundException {
        return authDAO.findByUserIdSecurity(loginId);
    }

    /**
     * 사용자 등록
     */
    @Override
    @Transactional
    public int insertUser(UserVO userVO) throws Exception {
        // TODO 동일한 계정이 있는지 확인 하는 로직 추 가
        UserVO checkLoginId = (UserVO) authDAO.findByUserIdSecurity(userVO.getLoginId());
        if(checkLoginId != null) {
            return -1;
        }
        String usid = userIdgn.getNextStringId();
        userVO.setUsid(usid);

        // 작성자 조회 및 등록
        if(jwtUtil.getWriter() != null && !jwtUtil.getWriter().equals("")) {
            userVO.setReg(jwtUtil.getWriter());
        }
        // 패스워드 암호화
        userVO.setPassword(bCryptPasswordEncoder.encode(userVO.getPassword()));
        // 사용자 등록
        int result = authDAO.insertUser(userVO);

        // 권한 등록
        Map<String, Object> authMap = new HashMap<>();
        authMap.put("usid", usid);
        authMap.put("authrt_cd", "STUDENT");
        authDAO.insertAuth(authMap);

        return result;
    }


}


