package com.takensoft.ai_lms.lms.auth.vo;

import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.*;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;

import java.time.LocalDateTime;
import java.util.Collection;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author  : 방선주
 * since   : 2024.05.09
 *
 * 사용자 관련 VO
 */

@Setter
@Getter
@ToString
@AllArgsConstructor
@NoArgsConstructor
public class UserVO implements UserDetails {

    // 사용자 아이디
    private String usid;
    // 로그인 아이디
    private String loginId;
    // 비밀번호
    private String password;
    // 사용자명
    private String userNm;
    // 이메일
    private String email;
    // 전화번호
    private String telno;
    // 계정 사용 여부
    private String useAt;
    // 등록자 명
    private String reg;
    // 등록일자
    private String registDt;
    // 수정자 명
    private String updusr;
    // 수정일자
    private String updtDt;
    // 권한
    @JsonIgnore
    private List<UserAuthorVO> author;

    // 계정이 가지곤 있는 권한 목록 리턴
    @Override
    public Collection<? extends GrantedAuthority> getAuthorities() {
        if (this.author != null) {
            if (this.author.size() > 0) {
                return this.author.stream().map(auth -> new SimpleGrantedAuthority(
                        auth.getAuthorCode()
                )).collect(Collectors.toList());
            } else {
                return null;
            }
        }
        return null;
    }

    // 계정의 id를 리턴
    @Override
    public String getUsername() {
        return loginId;
    }

    // 계정의 패스워드 리턴
    @Override
    public String getPassword() {
        return password;
    }

    /*
    // 계정이 만료되지 않았는지를 리턴
    @Override
    public boolean isAccountNonExpired() {
        return this.useAt;
    }
    // 계정이 잠겨있지 않은지를 리턴
    @Override
    public boolean isAccountNonLocked() {
        return this.useAt;
    }
    // 계정의 패스워드가 만료되지 않았는지 리턴
    @Override
    public boolean isCredentialsNonExpired() {
        return this.useAt;
    }
    //  계정이 사용가능한 계정인지를 리턴
    @Override
    public boolean isEnabled() {
        return this.useAt;
    }
    */
}