package com.takensoft.ai_lms.lms.auth.web;

import com.google.gson.Gson;
import com.google.gson.JsonObject;
import com.takensoft.ai_lms.lms.auth.service.AuthService;
import com.takensoft.ai_lms.lms.auth.vo.UserVO;
import io.swagger.v3.oas.annotations.Operation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author  : 방선주
 * since   : 2024.05.09
 * 사용자 관련 Controller
 */
@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping(value="/auth")
public class AuthController {

    private final AuthService authService;

    /**
     * @author  방선주
     * @since   2024.07.12
     * param   UserVO
     * @return
     * @throws  Exception
     *
     * 사용자 등록
     */
    @PostMapping("/insertUser.json")
    @Operation(summary = "사용자 등록")
    public String insertUser(@RequestBody UserVO userVO) throws Exception {
        Gson gson = new Gson();
        JsonObject response = new JsonObject();

        try {
            int result = authService.insertUser(userVO);


            if (result == -1) {
                response.addProperty("status", "fail");
                response.addProperty("message", "동일한 계정이 존재합니다.");
                return gson.toJson(response);
            }

            response.addProperty("status", "success");
            response.addProperty("message", "사용자가 등록되었습니다.");
            return gson.toJson(response);
        } catch (Exception e) {
            response.addProperty("status", "error");
            response.addProperty("message", e.getMessage());
            return gson.toJson(response);
        }


    }


}
