package com.takensoft.ai_lms.lms.board.web;


import com.takensoft.ai_lms.lms.board.service.BoardService;
import com.takensoft.ai_lms.lms.board.vo.BoardVO;
import com.takensoft.ai_lms.lms.file.service.FileService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author  : 박세훈
 * since   : 2024.07.25
 * 게시판 관련 Controller
 */
@RestController
//@Slf4j
@RequiredArgsConstructor
@RequestMapping(value = "/board")
public class BoardController {

    private final BoardService boardService;

    /**
     * @author 박세훈
     * @since 2024.07.25
     *
     * 게시글 등록
     */
    @PostMapping("/insert.json")
    public String insertBoard(@RequestBody BoardVO boardVO) throws Exception{
        try {
            int result = boardService.insertBoard(boardVO);
            if (result > 0 ) {
                return "success";
            } else {
                return "fail";
            }
        } catch (Exception e) {
            e.printStackTrace();
            return "Error";
        }
    }


    /**
     * @author 박세훈
     * @since 2024.07.25
     *
     * 게시글 전체 조회
     */
    @PostMapping("/findAll.json")
    public ResponseEntity<?> findAllBoard(@RequestBody HashMap<String, Object> params) throws Exception {
        HashMap<String, Object> result = new HashMap<>();

        // 전체 게시물 수 조회 및 추가
        result.put("totalBoard", boardService.boardCount(params));
        result.put("result", boardService.findAllBoard(params));


        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 박세훈
     * @since 2024.07.25
     *
     * 게시글 상세 조회
     */

    @PostMapping("/find.json")
    public ResponseEntity<?> findByBoardId(@RequestBody HashMap<String, Object> params) throws Exception {
        HashMap<String, Object> result = new HashMap<>();

        result.put("result", boardService.findByBoardId(params));
        return new ResponseEntity<>(result, HttpStatus.OK);
    }
    /**
     * @author 박세훈
     * @since 2024.07.25
     *
     * 게시글 수정
     */
    @PostMapping("/update.json")
    public String updateBoard(@RequestBody BoardVO boardVO) throws Exception {
        try {
            int result = boardService.updateBoard(boardVO);
            if (result > 0 ) {
                return "success";
            } else {
                return "fail";
            }
        } catch (Exception e){
            e.printStackTrace();
            return "Error";
        }
    }
    /**
     * @author 박세훈
     * @since 2024.07.25
     *
     * 게시글 삭제
     */
    @PostMapping("/delete.json")
    public String deleteBoard(@RequestBody Map<String, String> request) throws Exception {
        try{
            String bbsId = request.get("bbsId");
            int result = boardService.deleteBoard(bbsId);
            if (result > 0 ) {
                return "success";
            } else {
                return "fail";
            }
        } catch (Exception e){
            e.printStackTrace();
            return "Error";
        }
    }

    /**
     * @author 박세훈
     * @since 2024.07.26
     *
     * 게시글 검색
     */

    @PostMapping("/search.json")
    public ResponseEntity<?> searchBoard(@RequestBody HashMap<String, Object> params) throws Exception {
        HashMap<String, Object> result = new HashMap<>();

        List<HashMap<String, Object>> boardList = boardService.searchBoard(params);
        result.put("totalBoard", boardService.boardCount(params));
        result.put("result", boardList);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }



}
