package com.takensoft.ai_lms.lms.book.web;

import com.takensoft.ai_lms.lms.book.service.Impl.BookServiceImpl;
import com.takensoft.ai_lms.lms.book.vo.BookVO;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

/**
 * @author  : 구자현
 * @since   : 2024.07.25
 *
 * 교재 관련 Controller 클래스
 */
@RequiredArgsConstructor
@RestController
@RequestMapping("/book")
public class BookController {

    private final BookServiceImpl bookServiceImpl;

    /**
     * @author : 구자현
     * @since : 2024.07.25
     *
     * 전체 교재 목록 출력
     */
    @PostMapping("/findAll.json")
    public ResponseEntity<?> getAllBooks() {
        return new ResponseEntity<>(bookServiceImpl.getAllBooks(), HttpStatus.OK);
    }

    /**
     * @author : 구자현
     * @since : 2024.07.25
     *
     * 책의 상세 정보
     */
    @PostMapping("/find.json")
    public ResponseEntity<?> getBookById(@RequestBody BookVO bookVO) {
        return new ResponseEntity<>(bookServiceImpl.getBookById(bookVO.getBook_id()), HttpStatus.OK);
    }

    /**
     * @author : 구자현
     * @since : 2024.07.25
     *
     * 교재 등록
     */
    @PostMapping("/insert.json")
    public ResponseEntity<?> insertBook(@RequestBody BookVO bookVO) {
        return new ResponseEntity<>(bookServiceImpl.insertBook(bookVO), HttpStatus.OK);
    }

    /**
     * @author : 구자현
     * @since : 2024.07.25
     *
     * 교재 제목 수정
     */
    @PostMapping("/update.json")
    public ResponseEntity<?> updateBook(@RequestBody BookVO bookVO) {
        return new ResponseEntity<>(bookServiceImpl.updateBook(bookVO), HttpStatus.OK);
    }

    /**
     * @author : 구자현
     * @since : 2024.07.25
     *
     * 교재 삭제
     */
    @PostMapping("/delete.json")
    public ResponseEntity<?> deleteBook(@RequestBody BookVO bookVO) {
        return new ResponseEntity<>(bookServiceImpl.deleteBook(bookVO.getBook_id()), HttpStatus.OK);
    }

}