package com.takensoft.ai_lms.lms.class_book.web;

import com.takensoft.ai_lms.lms.class_book.service.ClassBookService;
import com.takensoft.ai_lms.lms.class_book.vo.ClassBookVO;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;

@RestController
@RequiredArgsConstructor
@RequestMapping(value = "/classBook")
public class ClassBookController {

    private final ClassBookService classBookService;

    /**
     * @author  박세훈
     * @since   2024.07.29
     * param   ClassBookDAO
     * @return
     * @throws  Exception
     *
     * 반 교재 등록
     */
    @PostMapping("/register.json")
    public ResponseEntity<Void> registerBook(@RequestBody List<ClassBookVO> classBookVO) throws Exception {
        classBookService.registerBook(classBookVO);
        return new ResponseEntity<>(HttpStatus.OK);
    }


    /**
     * @author  박세훈
     * @since   2024.07.29
     * param   ClassBookDAO
     * @return
     * @throws  Exception
     *
     * 반에 등록된 교재 조회
     */
    @PostMapping("/findAll.json")
    public ResponseEntity<?> findByBookId(@RequestBody HashMap<String, Object> params) throws Exception {
        HashMap<String, Object> result = new HashMap<>();

        result.put("result", classBookService.findByBookId(params));

        return new ResponseEntity<>(result, HttpStatus.OK);
    }


    /**
     * @author  박세훈
     * @since   2024.07.29
     * param   ClassBookDAO
     * @return
     * @throws  Exception

     * 반 교재 삭제
     */
    @PostMapping("/delete.json")
    public String deleteClassBook(@RequestBody ClassBookVO classBookVO) throws Exception {
        try {
            int result = classBookService.deleteClassBook(classBookVO);
            if (result > 0) {
                return "success";
            } else {
                return "fail";
            }
        } catch (Exception e) {
            e.printStackTrace();
            return "Error";
        }
    }

}
