package com.takensoft.ai_lms.lms.eval_problem.web;

import com.takensoft.ai_lms.lms.eval_problem.service.EvalProblemService;
import com.takensoft.ai_lms.lms.eval_problem.vo.EvalProblemVO;
import com.takensoft.ai_lms.lms.evaluation.vo.EvaluationVO;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author 권지수
 * @since 2024.07.29
 *
 * 단원 평가 Controller 클래스
 */

@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping(value = "/evalProblem")
public class EvalProblemController {

    private final EvalProblemService evalProblemService;

    /**
     * @author 권지수
     * @since 2024.07.29
     *
     * 단원 평가 문제 입력
     */
    @PostMapping(path = "/insertEvalProblem.json")
    public ResponseEntity<?> insertEvalProblem(@RequestBody EvalProblemVO evalProblemVO) throws Exception {
        int result = evalProblemService.insertEvalProblem(evalProblemVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.07.30
     *
     * 특정 단원의 문제 수 조회
     */
    @PostMapping(path = "/unitProblemNum.json")
    public ResponseEntity<?> unitProblemNum(@RequestBody EvalProblemVO evalProblemVO) throws Exception {
        int result = evalProblemService.unitProblemNum(evalProblemVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.08.01
     *
     * 단원 평가에 등록된 문제 삭제
     */
    @PostMapping(path = "/deleteEvalProblem.json")
    public ResponseEntity<?> deleteEvalProblem(@RequestBody EvalProblemVO evalProblemVO) throws Exception {
        int result = evalProblemService.deleteEvalProblem(evalProblemVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }
}
