package com.takensoft.ai_lms.lms.evaluation.service.Impl;

import com.takensoft.ai_lms.common.idgen.service.IdgenService;
import com.takensoft.ai_lms.lms.evaluation.dao.EvaluationDAO;
import com.takensoft.ai_lms.lms.evaluation.service.EvaluationService;
import com.takensoft.ai_lms.lms.evaluation.vo.EvaluationVO;
import com.takensoft.ai_lms.lms.problem.vo.SearchVO;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author 권지수
 * @since 2024.07.29
 *
 * 단원 평가 ServiceImpl 클래스
 */

@Service("evaluationService")
@RequiredArgsConstructor
public class EvaluationServiceImpl extends EgovAbstractServiceImpl implements EvaluationService {

    private final EvaluationDAO evaluationDAO;
    private final IdgenService evalIdgn;

    /**
     * @author 권지수
     * @since 2024.07.29
     *
     * 단원 평가 정보 입력
     */
    public int insertEvaluation(EvaluationVO evaluationVO) throws Exception {
        String evaluationId = evalIdgn.getNextStringId();
        evaluationVO.setEvalId(evaluationId);

        return evaluationDAO.insertEvaluation(evaluationVO);
    }

    /**
     * @author 권지수
     * @since 2024.07.29
     *
     * 단원 평가 정보 조회
     */
    public EvaluationVO evaluationInfo(EvaluationVO evaluationVO) throws Exception {
        return evaluationDAO.evaluationInfo(evaluationVO);
    }

    /**
     * @author 권지수
     * @since 2024.07.29
     *
     * 특정 단원 평가 정보 조회
     */
    public List<EvaluationVO> evaluationUnitList(SearchVO searchVO) throws Exception {
        return evaluationDAO.evaluationUnitList(searchVO);
    }

    /**
     * @author 권지수
     * @since 2024.07.29
     *
     * 단원 평가 정보 수정
     */
    public int updateEvaluation(EvaluationVO evaluationVO) throws Exception {
        return evaluationDAO.updateEvaluation(evaluationVO);
    }

    /**
     * @author 권지수
     * @since 2024.07.29
     *
     * 단원 평가 정보 삭제
     */
    public int deleteEvaluation(EvaluationVO evaluationVO) throws Exception {
        return evaluationDAO.deleteEvaluation(evaluationVO);
    }

}
