package com.takensoft.ai_lms.lms.evaluation.web;

import com.takensoft.ai_lms.lms.evaluation.service.EvaluationService;
import com.takensoft.ai_lms.lms.evaluation.vo.EvaluationVO;
import com.takensoft.ai_lms.lms.problem.vo.ProblemVO;
import com.takensoft.ai_lms.lms.problem.vo.SearchVO;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @author 권지수
 * @since 2024.07.29
 *
 * 단원 평가 Controller 클래스
 */

@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping(value = "/evaluation")
public class EvaluationController {

    private final EvaluationService evaluationService;

    /**
     * @author 권지수
     * @since 2024.07.29
     *
     * 단원 평가 정보 입력
     */
    @PostMapping(path = "/insertEvaluation.json")
    public ResponseEntity<?> insertEvaluation(@RequestBody EvaluationVO evaluationVO) throws Exception {
        int result = evaluationService.insertEvaluation(evaluationVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.07.29
     *
     * 단원 평가 정보 조회
     */
    @PostMapping(path = "/evaluationInfo.json")
    public ResponseEntity<?> evaluationInfo(@RequestBody EvaluationVO evaluationVO) throws Exception {
        EvaluationVO result = evaluationService.evaluationInfo(evaluationVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.07.29
     *
     * 특정 단원 평가 정보 조회
     */
    @PostMapping(path = "/evaluationUnitList.json")
    public ResponseEntity<?> evaluationUnitList(@RequestBody SearchVO searchVO) throws Exception {
        List<EvaluationVO> result = evaluationService.evaluationUnitList(searchVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.07.29
     *
     * 단원 평가 정보 수정
     */
    @PostMapping(path = "/updateEvaluation.json")
    public ResponseEntity<?> updateEvaluation(@RequestBody EvaluationVO evaluationVO) throws Exception {
        int result = evaluationService.updateEvaluation(evaluationVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.07.29
     *
     * 단원 평가 정보 삭제
     */
    @PostMapping(path = "/deleteEvaluation.json")
    public ResponseEntity<?> deleteEvaluation(@RequestBody EvaluationVO evaluationVO) throws Exception {
        int result = evaluationService.deleteEvaluation(evaluationVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }
}
