package com.takensoft.ai_lms.lms.file.service.impl;

import com.takensoft.ai_lms.common.idgen.service.IdgenService;
import com.takensoft.ai_lms.lms.file.dao.FileDAO;
import com.takensoft.ai_lms.lms.file.service.FileService;
import com.takensoft.ai_lms.lms.file.vo.FileManageVO;
import com.takensoft.ai_lms.lms.file.vo.FileVO;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.HashMap;
import java.util.List;
import java.util.UUID;

@Service("FileService")
@RequiredArgsConstructor
public class FileServiceImpl extends EgovAbstractServiceImpl implements FileService {
    private final FileDAO fileDAO;

    private final IdgenService fileMngIdgn;
    private final IdgenService fileIdgn;

    // 파일 정보 조회
    // @Override
    public List<HashMap<String, Object>> findByFileId(HashMap<String, Object> params) throws Exception {
        return fileDAO.findByFileId(params);
    }

    /*
     * @author  : 박민혁
     * since   : 2024.08.01
     *
     * 파일 업로드 기능 (파일 매니지 아이디 및 파일 정보 올리면서)
     */
    public String fileUpload(MultipartFile[] files) throws Exception {
        FileManageVO fileManageVO = new FileManageVO();
        String fileMngId = fileMngIdgn.getNextStringId();
        fileManageVO.setFileMngId(fileMngId);

        // 파일 매니지 저장
        fileDAO.fileManageInsert(fileMngId);

        String rootPath = "C:\\ai_lms\\cmmmfile\\";

        for (MultipartFile file : files) {
            String originalFileName = file.getOriginalFilename();
            String fileName = UUID.randomUUID().toString() + "_" + originalFileName;

            File tempDir = new File(rootPath);
            if (!tempDir.exists()) {
                tempDir.mkdirs();
            }

            Path savePath = Paths.get(rootPath + fileName);

            // 파일 저장
            Files.copy(file.getInputStream(), savePath);

            // 단일 파일들 저장
            FileVO fileVO = new FileVO();

            String fileId = fileIdgn.getNextStringId();
            fileVO.setFileId(fileId);
            fileVO.setFileMngId(fileMngId);
            fileVO.setFileNm(originalFileName);
            fileVO.setFileEncptNm(fileName);
            fileVO.setFileSz(String.valueOf(file.getSize()));
            fileVO.setFileClsf(null);
            fileVO.setFileApath(savePath.toString());
            fileVO.setFileExtn(fileName.substring(fileName.lastIndexOf(".") + 1));

            // 상대 경로 설정
            String relativePath = savePath.toString().replace(rootPath, "");
            fileVO.setFileRpath(relativePath);

            fileDAO.fileInsert(fileVO);
        }

        return fileMngId;
    }
}
