package com.takensoft.ai_lms.lms.photo.service.Impl;

import com.takensoft.ai_lms.common.idgen.service.IdgenService;
import com.takensoft.ai_lms.lms.photo.dao.PhotoMngDAO;
import com.takensoft.ai_lms.lms.photo.service.PhotoMngService;
import com.takensoft.ai_lms.lms.photo.vo.PhotoMngVO;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author  : 김건택
 * @since   : 2024.07.25
 *
 * 사진첩 관련 ServiceImpl 클래스
 */
@Service("photoMngService")
@RequiredArgsConstructor
public class PhotoMngServiceImpl extends EgovAbstractServiceImpl implements PhotoMngService {

    private final PhotoMngDAO photoMngDAO;
    private final IdgenService photoMngIdgn;

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진첩 목록 출력
     */
    @Override
    public List<PhotoMngVO> photoMngList() throws Exception {
        return photoMngDAO.photoMngList();
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진첩 등록
     */
    @Override
    public int insertPhotoMng(PhotoMngVO photoMngVO) throws Exception {
        String photoMngId = photoMngIdgn.getNextStringId();
        photoMngVO.setPhotoMngId(photoMngId);
        int result = photoMngDAO.insertPhotoMng(photoMngVO);
        return result;
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진첩 수정
     */
    @Override
    public int updatePhotoMng(PhotoMngVO photoMngVO) throws Exception {
        int result = photoMngDAO.updatePhotoMng(photoMngVO);
        return result;
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진첩 삭제
     */
    @Override
    public int deletePhotoMng(PhotoMngVO photoMngVO) throws Exception {
        int result = photoMngDAO.deletePhotoMng(photoMngVO);
        return result;
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진첩 상세 정보
     */
    @Override
    public List<PhotoMngVO> photoMngDetail(PhotoMngVO photoMngVO) throws Exception {
        return photoMngDAO.photoMngDetail(photoMngVO);
    }
}
