package com.takensoft.ai_lms.lms.photo.service.Impl;

import com.takensoft.ai_lms.common.idgen.service.IdgenService;
import com.takensoft.ai_lms.lms.photo.dao.PhotoDAO;
import com.takensoft.ai_lms.lms.photo.service.PhotoService;
import com.takensoft.ai_lms.lms.photo.vo.PhotoVO;
import com.takensoft.ai_lms.lms.unit.service.UnitService;
import com.takensoft.ai_lms.lms.unit.vo.UnitVO;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author  : 김건택
 * @since   : 2024.07.25
 *
 * 사진 관련 ServiceImpl 클래스
 */
@Service("photoService")
@RequiredArgsConstructor
public class PhotoServiceImpl extends EgovAbstractServiceImpl implements PhotoService {

    private final PhotoDAO photoDAO;
    private final IdgenService photoIdgn;

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진 목록 출력
     */
    @Override
    public List<PhotoVO> photoList(PhotoVO photoVO) throws Exception {
        return photoDAO.photoList(photoVO);
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진 등록
     */
    @Override
    public int insertPhoto(PhotoVO photoVO) throws Exception {
        String photoId = photoIdgn.getNextStringId();
        photoVO.setPhotoId(photoId);
        int result = photoDAO.insertPhoto(photoVO);
        return result;
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진 수정
     */
    @Override
    public int updatePhoto(PhotoVO photoVO) throws Exception {
        int result = photoDAO.updatePhoto(photoVO);
        return result;
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진 삭제
     */
    @Override
    public int deletePhoto(PhotoVO photoVO) throws Exception {
        int result = photoDAO.deletePhoto(photoVO);
        return result;
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진 상세 정보
     */
    @Override
    public List<PhotoVO> photoDetail(PhotoVO photoVO) throws Exception {
        return photoDAO.photoDetail(photoVO);
    }
}
