package com.takensoft.ai_lms.lms.photo.web;

import com.takensoft.ai_lms.lms.photo.service.PhotoService;
import com.takensoft.ai_lms.lms.photo.vo.PhotoVO;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @author  : 김건택
 * @since   : 2024.07.25
 *
 * 사진 관련 Controller 클래스
 */
@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping(value="/photo")
public class PhotoController {

    private final PhotoService photoService;

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진 목록 출력
     */
    @PostMapping(path = "/photoList.json")
    public ResponseEntity<?> unitList(@RequestBody PhotoVO photoVO) throws Exception {
        List<PhotoVO> result = photoService.photoList(photoVO);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진 등록
     */
    @PostMapping(path = "/insertPhoto.json")
    public ResponseEntity<?> insertUnit(@RequestBody PhotoVO photoVO) throws Exception {
        int result = photoService.insertPhoto(photoVO);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진 수정
     */
    @PostMapping(path = "/updatePhoto.json")
    public ResponseEntity<?> updateUnit(@RequestBody PhotoVO photoVO) throws Exception {
        int result = photoService.updatePhoto(photoVO);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진 삭제
     */
    @PostMapping(path = "/deletePhoto.json")
    public ResponseEntity<?> deleteUnit(@RequestBody PhotoVO photoVO) throws Exception {
        int result = photoService.deletePhoto(photoVO);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진 상세 정보
     */
    @PostMapping(path = "/photoDetail.json")
    public ResponseEntity<?> unitDetail(@RequestBody PhotoVO photoVO) throws Exception {
        List<PhotoVO> result = photoService.photoDetail(photoVO);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }
}
