package com.takensoft.ai_lms.lms.photo.web;

import com.takensoft.ai_lms.lms.photo.service.PhotoMngService;
import com.takensoft.ai_lms.lms.photo.vo.PhotoMngVO;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @author  : 김건택
 * @since   : 2024.07.25
 *
 * 사진첩 관련 Controller 클래스
 */
@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping(value="/photoMng")
public class PhotoMngController {

    private final PhotoMngService photoMngService;

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진첩 목록 출력
     */
    @PostMapping(path = "/photoMngList.json")
    public ResponseEntity<?> photoMngList() throws Exception {
        List<PhotoMngVO> result = photoMngService.photoMngList();
        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진첩 등록
     */
    @PostMapping(path = "/insertPhotoMng.json")
    public ResponseEntity<?> insertPhotoMng(@RequestBody PhotoMngVO photoMngVO) throws Exception {
        int result = photoMngService.insertPhotoMng(photoMngVO);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진첩 수정
     */
    @PostMapping(path = "/updatePhotoMng.json")
    public ResponseEntity<?> updatePhotoMng(@RequestBody PhotoMngVO photoMngVO) throws Exception {
        int result = photoMngService.updatePhotoMng(photoMngVO);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진첩 삭제
     */
    @PostMapping(path = "/deletePhotoMng.json")
    public ResponseEntity<?> deletePhotoMng(@RequestBody PhotoMngVO photoMngVO) throws Exception {
        int result = photoMngService.deletePhotoMng(photoMngVO);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 사진첩 상세 정보
     */
    @PostMapping(path = "/photoMngDetail.json")
    public ResponseEntity<?> photoMngDetail(@RequestBody PhotoMngVO photoMngVO) throws Exception {
        List<PhotoMngVO> result = photoMngService.photoMngDetail(photoMngVO);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }
}
