package com.takensoft.ai_lms.lms.problem.service.Impl;

import com.takensoft.ai_lms.common.idgen.service.IdgenService;
import com.takensoft.ai_lms.lms.eval_problem.vo.EvalProblemVO;
import com.takensoft.ai_lms.lms.problem.dao.ProblemDAO;
import com.takensoft.ai_lms.lms.problem.service.ProblemService;
import com.takensoft.ai_lms.lms.problem.vo.ProblemDetailVO;
import com.takensoft.ai_lms.lms.problem.vo.ProblemVO;
import com.takensoft.ai_lms.lms.problem.vo.SearchVO;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author 권지수
 * @since 2024.07.25
 *
 * 문제 ServiceImpl 클래스
 */

@Service("problemService")
@RequiredArgsConstructor
public class ProblemServiceImpl extends EgovAbstractServiceImpl implements ProblemService {

    private final ProblemDAO problemDAO;
    private final IdgenService problemIdgn;
    private final IdgenService problemDtlIdgn;


    /**
     * @author 권지수
     * @since 2024.07.25
     *
     * 문제 데이터 조회
     */
    @Override
    public ProblemVO problemInfo(ProblemVO problemVO) throws Exception {
        return problemDAO.problemInfo(problemVO);
    }

    /**
     * @author 권지수
     * @since 2024.07.25
     *
     * 문제 선지 리스트 조회
     */
    @Override
    public List<ProblemDetailVO> problemDetailList(ProblemVO problemVO) throws Exception {
        return problemDAO.problemDetailList(problemVO);
    }

    /**
     * @author 권지수
     * @since 2024.07.26
     *
     * 문제 정보 입력
     */
    @Override
    public int insertProblem(ProblemVO problemVO) throws Exception {
        String problemId = problemIdgn.getNextStringId();
        problemVO.setPrblmId(problemId);

        return problemDAO.insertProblem(problemVO);
    }

    /**
     * @author 권지수
     * @since 2024.07.26
     *
     * 문제 상세 정보 입력
     */
    @Override
    public int insertProblemDetail(ProblemDetailVO problemDetailVO) throws Exception {
        String problemDtlId = problemDtlIdgn.getNextStringId();
        problemDetailVO.setPrblmDtlId(problemDtlId);

        return problemDAO.insertProblemDetail(problemDetailVO);
    }

    /**
     * @author 권지수
     * @since 2024.07.26
     *
     * 문제 정보 수정
     */
    public int updateProblem(ProblemVO problemVO) throws Exception {
        return problemDAO.updateProblem(problemVO);
    }

    /**
     * @author 권지수
     * @since 2024.07.26
     *
     * 문제 상세 정보 수정
     */
    public int updateProblemDetail(ProblemDetailVO problemDetailVO) throws Exception {
        return problemDAO.updateProblemDetail(problemDetailVO);
    }

    /**
     * @author 권지수
     * @since 2024.07.26
     *
     * 문제 정보 삭제
     */
    public int deleteProblem(ProblemVO problemVO) throws Exception {
        return problemDAO.deleteProblem(problemVO);
    }

    /**
     * @author 권지수
     * @since 2024.07.30
     *
     * 전체 문제 목록 조회
     */
    public List<ProblemVO> problemList(SearchVO searchVO) throws Exception {
        return problemDAO.problemList(searchVO);
    }

    /**
     * @author 권지수
     * @since 2024.07.30
     *
     * 특정 단원 평가의 문제 목록 조회
     */
    public List<ProblemVO> evaluationProblemList(SearchVO searchVO) throws Exception {
        return problemDAO.evaluationProblemList(searchVO);
    }
}
