package com.takensoft.ai_lms.lms.problem.web;

import com.takensoft.ai_lms.lms.auth.vo.UserVO;
import com.takensoft.ai_lms.lms.eval_problem.vo.EvalProblemVO;
import com.takensoft.ai_lms.lms.problem.service.ProblemService;
import com.takensoft.ai_lms.lms.problem.vo.ProblemDetailVO;
import com.takensoft.ai_lms.lms.problem.vo.ProblemVO;
import com.takensoft.ai_lms.lms.problem.vo.SearchVO;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;

/**
 * @author 권지수
 * @since 2024.07.25
 *
 * 문제 Controller 클래스
 */

@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping(value = "/problem")
public class ProblemController {

    private final ProblemService problemService;

    /**
     * @author 권지수
     * @since 2024.07.25
     *
     * 문제 정보 조회
     */
    @PostMapping(path = "/problemInfo.json")
    public ResponseEntity<?> problemInfo(@RequestBody ProblemVO problemVO) throws Exception {
        HashMap<String, Object> result = new HashMap<>();

        result.put("problem", problemService.problemInfo(problemVO));
        result.put("problemDetail", problemService.problemDetailList(problemVO));

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.07.26
     *
     * 문제 정보 입력
     */
    @PostMapping(path = "/insertProblem.json")
    public ResponseEntity<?> insertProblem(@RequestBody ProblemVO problemVO) throws Exception {
        int result = problemService.insertProblem(problemVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.07.26
     *
     * 문제 상세 정보 입력
     */
//    @PostMapping(path = "/insertProblemDetail.json")
//    public ResponseEntity<?> insertProblemDetail(@RequestBody ProblemDetailVO problemDetailVO) throws Exception {
//        int result = problemService.insertProblemDetail(problemDetailVO);
//
//        return new ResponseEntity<>(result, HttpStatus.OK);
//    }

    /**
     * @author 권지수
     * @since 2024.07.26
     *
     * 문제 상세 정보 입력 (리스트)
     */
    @PostMapping(path = "/insertProblemDetail.json")
    public ResponseEntity<?> insertProblemDetail(@RequestBody List<ProblemDetailVO> problemDetailVOList) throws Exception {
        int result = 0;

        for(ProblemDetailVO problemDetailVO: problemDetailVOList) {
            problemService.insertProblemDetail(problemDetailVO);
            result++;
        }

        //String result =

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.07.26
     *
     * 문제 정보 수정
     */
    @PostMapping(path = "/updateProblem.json")
    public ResponseEntity<?> updateProblem(@RequestBody ProblemVO problemVO) throws Exception {
        int result = problemService.updateProblem(problemVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.07.26
     *
     * 문제 상세 정보 수정 (리스트)
     */
    @PostMapping(path = "/updateProblemDetail.json")
    public ResponseEntity<?> updateProblemDetail(@RequestBody List<ProblemDetailVO> problemDetailVOList) throws Exception {
        int result = 0;

        for(ProblemDetailVO problemDetailVO: problemDetailVOList) {
            problemService.updateProblemDetail(problemDetailVO);
            result++;
        }

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.07.26
     *
     * 문제 정보 삭제
     */
    @PostMapping(path = "/deleteProblem.json")
    public ResponseEntity<?> deleteProblem(@RequestBody ProblemVO problemVO) throws Exception {
        int result = problemService.deleteProblem(problemVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.07.26
     *
     * 전체 문제 목록 조회
     */
    @PostMapping(path = "/problemList.json")
    public ResponseEntity<?> problemList(@RequestBody SearchVO searchVO) throws Exception {
        List<ProblemVO> result = problemService.problemList(searchVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.07.26
     *
     * 특정 단원 평가의 문제 목록 조회
     */
    @PostMapping(path = "/evaluationProblemList.json")
    public ResponseEntity<?> evaluationProblemList(@RequestBody SearchVO searchVO) throws Exception {
        List<ProblemVO> result = problemService.evaluationProblemList(searchVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }
}
