package com.takensoft.ai_lms.lms.problem_log.web;

import com.takensoft.ai_lms.lms.problem.vo.ProblemVO;
import com.takensoft.ai_lms.lms.problem_log.service.ProblemLogService;
import com.takensoft.ai_lms.lms.problem_log.vo.ProblemLogVO;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author 권지수
 * @since 2024.08.01
 *
 * 문제 풀이 로그 Controller 클래스
 */

@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping(value = "/problemLog")
public class ProblemLogController {

    private final ProblemLogService problemLogService;

    /**
     * @author 권지수
     * @since 2024.08.01
     *
     * 문제 풀이 로그 정보 입력
     */
    @PostMapping(path = "/insertProblemLog.json")
    public ResponseEntity<?> insertProblemLog(@RequestBody ProblemLogVO problemLogVO) throws Exception {
        int result = problemLogService.insertProblemLog(problemLogVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.08.02
     *
     * 문제 풀이 로그 정보 수정
     */
    @PostMapping(path = "/updateProblemLog.json")
    public ResponseEntity<?> updateProblemLog(@RequestBody ProblemLogVO problemLogVO) throws Exception {
        int result = problemLogService.updateProblemLog(problemLogVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.08.02
     *
     * 문제 풀이 로그 정보 삭제
     */
    @PostMapping(path = "/deleteProblemLog.json")
    public ResponseEntity<?> deleteProblemLog(@RequestBody ProblemLogVO problemLogVO) throws Exception {
        int result = problemLogService.deleteProblemLog(problemLogVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author 권지수
     * @since 2024.08.02
     *
     * 문제 풀이 로그 정보 조회
     */
    @PostMapping(path = "/problemLogInfo.json")
    public ResponseEntity<?> problemLogInfo(@RequestBody ProblemLogVO problemLogVO) throws Exception {
        ProblemLogVO result = problemLogService.problemLogInfo(problemLogVO);

        return new ResponseEntity<>(result, HttpStatus.OK);
    }
}
