package com.takensoft.ai_lms.lms.schedule.web;

import com.google.gson.Gson;
import com.google.gson.JsonObject;
import com.takensoft.ai_lms.lms.schedule.service.ScheduleService;
import com.takensoft.ai_lms.lms.schedule.vo.ScheduleVO;
import io.swagger.v3.oas.annotations.Operation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author 이은진
 * @since 2024.07.29
 */

@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping(value = "/schedule")
public class ScheduleController {

    private final ScheduleService scheduleService;

    /**
     * 학습 일정 등록
     */
    @PostMapping("/insertSchedule.json")
    @Operation(summary = "스케줄 등록")
    public String insertSchedule(@RequestBody ScheduleVO schedulevO) throws Exception {
        Gson gson = new Gson();
        JsonObject response = new JsonObject();

        try {
            int result = scheduleService.insertSchedule(schedulevO);
            if (result > 0) {
                response.addProperty("status", "success");
                response.addProperty("message", "학습 일정이 등록되었습니다.");
                return gson.toJson(response);
            } else {
                response.addProperty("message", "학습 일정 등록 실패");
                return gson.toJson(response);
            }
        } catch (Exception e) {
            response.addProperty("status", "error");
            response.addProperty("message", e.getMessage());
            return gson.toJson(response);
        }
    }

    /**
     * 학습 일정 출력
     */
    @PostMapping("/selectSchedule.json")
    @Operation(summary = "스케줄 출력")
    public List<HashMap<String, Object>> selectSchedule(@RequestBody HashMap<String, Object> stdId) throws Exception {
        return scheduleService.selectSchedule(stdId);
    }


    /**
     * 학습 일정 수정
     */
    @PostMapping(value = "/scheduleUpdate.json")
    @Operation(summary = "스케줄 수정")
    public String scheduleUpdate(@RequestBody ScheduleVO scheduleVO) throws Exception {
        Gson gson = new Gson();
        JsonObject response = new JsonObject();

        try {
            int result = scheduleService.scheduleUpdate(scheduleVO);
            if (result > 0) {
                response.addProperty("status", "success");
                response.addProperty("message", "학습 일정이 수정되었습니다.");
                return gson.toJson(response);
            } else {
                response.addProperty("message", "학습 일정 수정 실패");
                return gson.toJson(response);
            }
        } catch (Exception e) {
            response.addProperty("status", "error");
            response.addProperty("message", e.getMessage());
            return gson.toJson(response);
        }
    }


    /**
     * 학습 일정 삭제
     */
    @PostMapping(value = "/scheduleDelete.json")
    @Operation(summary = "스케줄 삭제")
    public String scheduleDelete(@RequestBody Map<String, String> request) throws Exception {
        Gson gson = new Gson();
        JsonObject response = new JsonObject();

        String scheduleId = request.get("scheduleId");
        int result = scheduleService.scheduleDelete(scheduleId);
        try {
            if (result > 0) {
                response.addProperty("status", "success");
                response.addProperty("message", "학습 일정이 삭제되었습니다.");
                return gson.toJson(response);
            } else {
                response.addProperty("message", "학습 일정 삭제 실패");
                return gson.toJson(response);
            }
        } catch (Exception e) {
            response.addProperty("status", "error");
            response.addProperty("message", e.getMessage());
            return gson.toJson(response);
        }
    }
}
