package com.takensoft.ai_lms.lms.survey.service.Impl;


import com.takensoft.ai_lms.common.idgen.service.IdgenService;
import com.takensoft.ai_lms.lms.survey.dao.SurveyDAO;
import com.takensoft.ai_lms.lms.survey.service.SurveyService;
import com.takensoft.ai_lms.lms.survey.vo.SurveyDetailVO;
import com.takensoft.ai_lms.lms.survey.vo.SurveyVO;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;


/**
 * @author : 박세훈
 * since   : 2024.07.29
 * <p>
 * 설문 조사 관련 ServiceImpl
 */
@Service("surveyService")
@RequiredArgsConstructor
public class SurveyServiceImpl extends EgovAbstractServiceImpl implements SurveyService {

    private final SurveyDAO surveyDAO;

    private final IdgenService surveyIdgn;

    private final IdgenService surveyDetailIdgn;

    // 설문 조사 등록
    @Override
    public int insertSurvey(SurveyVO surveyVO) throws Exception {
        String srvyId = surveyIdgn.getNextStringId();
        surveyVO.setSrvyId(srvyId);
        return surveyDAO.insertSurvey(surveyVO);
    }

    // 설문 조사 조회
    @Override
    public List<SurveyVO> surveyList(SurveyVO surveyVO) throws Exception {
        return surveyDAO.surveyList(surveyVO);
    }

    // 설문 조사 수정
    @Override
    public int updateSurvey(SurveyVO surveyVO) throws Exception {
        return surveyDAO.updateSurvey(surveyVO);
    }

    // 설문 조사 삭제
    @Transactional
    @Override
    public void deleteSurveyWithDetails(String srvyId) throws Exception {
        surveyDAO.deleteSurveyDetail(srvyId);
        surveyDAO.deleteSurvey(srvyId);
    }



    // 설문 조사 상세 정보
    @Override
    public void insertSurveyDetail(List<SurveyDetailVO> surveyDetailVO) throws Exception {
        for (SurveyDetailVO detail : surveyDetailVO) {
            String srvyDtlId = surveyDetailIdgn.getNextStringId();
            detail.setSrvyDtlId(srvyDtlId);
        }
        surveyDAO.insertSurveyDetail(surveyDetailVO);
    }

    // 설문 조사 상세 정보 조회
    @Override
    public List<SurveyDetailVO> surveyDetailList(SurveyDetailVO surveyDetailVO) throws Exception {
        return surveyDAO.surveyDetailList(surveyDetailVO);
    }
}
