package com.takensoft.ai_lms.lms.survey.web;


import com.takensoft.ai_lms.lms.survey.service.SurveyService;
import com.takensoft.ai_lms.lms.survey.vo.SurveyDetailVO;
import com.takensoft.ai_lms.lms.survey.vo.SurveyVO;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @author  : 박세훈
 * since   : 2024.07.29
 *
 * 설문 조사 관련 Controller
 */

@RestController
@RequestMapping(value = "/survey")
@RequiredArgsConstructor
public class SurveyController {

    private final SurveyService surveyService;


    // 설문 조사 등록
    @PostMapping("/insert.json")
    public String insertSurvey(@RequestBody SurveyVO surveyVO) throws Exception {
        try {
            int result = surveyService.insertSurvey(surveyVO);
            if (result > 0) {
                return "success";
            } else {
                return "fail";
            }
        } catch (Exception e ) {
            return "Error";
        }
    }

    // 설문 조사 상세 등록
    @PostMapping("/insertDetail.json")
    public ResponseEntity<Void> insertDetailSurvey(@RequestBody List<SurveyDetailVO> surveyDetailVO) throws Exception {
        surveyService.insertSurveyDetail(surveyDetailVO);
        return new ResponseEntity<>(HttpStatus.OK);
    }


    // 설문 조사 조회
    @PostMapping("/list.json")
    public List<SurveyVO> surveyList(SurveyVO surveyVO) throws Exception {
        return surveyService.surveyList(surveyVO);
    }

    // 설문 조사 상세 조회
    @PostMapping("detailList.json")
    public List<SurveyDetailVO> surveyDetailVOList(@RequestBody SurveyDetailVO surveyDetailVO) throws Exception {
        return surveyService.surveyDetailList(surveyDetailVO);
    }


    // 설문 조사 수정
    @PostMapping("/update.json")
    public String updateSurvey (@RequestBody SurveyVO surveyVO) throws Exception {
        try {
            int result = surveyService.updateSurvey(surveyVO);
            if (result > 0) {
                return "success";
            } else {
                return "fail";
            }
        }catch (Exception e) {
            return "Error";
        }
    }


    // 설문 조사 삭제(연관된 설문 조사 상세도 삭제됨)
    @PostMapping("/delete.json")
    public ResponseEntity<Void> deleteSurvey (@RequestBody SurveyVO surveyVO) throws Exception {
        surveyService.deleteSurveyWithDetails(surveyVO.getSrvyId());
        return new ResponseEntity<>(HttpStatus.OK);
    }


}
