package com.takensoft.ai_lms.lms.text.service.Impl;

import com.takensoft.ai_lms.common.idgen.service.IdgenService;
import com.takensoft.ai_lms.lms.text.dao.TextDAO;
import com.takensoft.ai_lms.lms.text.service.TextService;
import com.takensoft.ai_lms.lms.text.vo.TextVO;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.servlet.ModelAndView;

import java.util.HashMap;
import java.util.List;

/**
 * @author : 이은진
 * @since : 2024.07.25
 */

@Service("textService")
@RequiredArgsConstructor
public class TextServiceImpl implements TextService {

    private final TextDAO textDAO;
    private final IdgenService textIdgn;

    /**
     * 지문 등록
     */
    @Override
    @Transactional
    public int insertText(TextVO textVO) throws Exception {
        String textID = textIdgn.getNextStringId();
        textVO.setTextId(textID);
        return textDAO.insertText(textVO);
    }

    /**
     * 지문 리스트 조회
     */
    @Override
    public List<HashMap<String, Object>> selectTextList(HashMap<String, Object> params) throws Exception {
        int page = Integer.parseInt(params.get("page").toString());
        int pageSize = Integer.parseInt(params.get("pageSize").toString());

        int startIndex = (page - 1) * pageSize;
        params.put("startIndex", startIndex);
        params.put("pageSize", pageSize);
        return textDAO.selectTextList(params);
    }

    /**
     * 지문 수 조회
     */
    @Override
    public int textCount(HashMap<String, Object> params) throws Exception {
        return textDAO.textCount(params);
    }

    /**
     * 지문 출력
     */
    @Override
    public List<HashMap<String, Object>> selectOneText(HashMap<String, Object> params) throws Exception {
        return textDAO.selectOneText(params);
    }

    /**
     * 지문 수정
     */
    @Override
    public int textUpdate(TextVO textVO) throws Exception {
        return textDAO.textUpdate(textVO);
    }

    /**
     * 지문 삭제
     */
    @Override
    public int textDelete(String textId) throws Exception {
        return textDAO.textDelete(textId);
    }


    /**
     * 지문 검색
     */
    @Override
    public List<HashMap<String, Object>> searchText(HashMap<String, Object> params) throws Exception {
        return textDAO.searchText(params);
    }
}
