package com.takensoft.ai_lms.lms.text.web;

import com.google.gson.Gson;
import com.google.gson.JsonObject;
import com.takensoft.ai_lms.lms.text.service.TextService;
import com.takensoft.ai_lms.lms.text.vo.TextVO;
import io.swagger.v3.oas.annotations.Operation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author 이은진
 * @since 2024.07.25
 */


@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping(value = "/text")
public class TextController {

    private final TextService TextService;

    /**
     * 지문 등록
     */
    @PostMapping("/insertText.json")
    @Operation(summary = "지문 등록")
    public String insertText(@RequestBody TextVO textVO) throws Exception {
        Gson gson = new Gson();
        JsonObject response = new JsonObject();

        try {
            int result = TextService.insertText(textVO);
            if (result > 0) {
                response.addProperty("status", "success");
                response.addProperty("message", "지문이 등록되었습니다.");
                return gson.toJson(response);
            } else {
                response.addProperty("message", "지문 등록 실패");
                return gson.toJson(response);
            }
        } catch (Exception e) {
            response.addProperty("status", "error");
            response.addProperty("message", e.getMessage());
            return gson.toJson(response);
        }
    }


    /**
     * 지문 리스트 조회
     */
    @PostMapping("/selectTextList.json")
    @Operation(summary = "지문 리스트 조회")
    public HashMap<String, Object> getTextList(@RequestBody HashMap<String, Object> params) throws Exception {
        HashMap<String, Object> result = new HashMap<>();

        int page = Integer.parseInt(params.get("page").toString());
        int pageSize = Integer.parseInt(params.get("pageSize").toString());

        int totalText = TextService.textCount(params);
        result.put("totalText", totalText);
        result.put("texts", TextService.selectTextList(params));

        return result;
    }

    /**
     * 지문 출력
     */
    @PostMapping("/selectOneText.json")
    @Operation(summary = "지문 출력")
    public List<HashMap<String, Object>> selectOneText(@RequestBody HashMap<String, Object> textId) throws Exception {
        return TextService.selectOneText(textId);
    }


    /**
     * 지문 수정
     */
    @PostMapping(value = "/textUpdate.json")
    @Operation(summary = "지문 수정")
    public String textUpdate(@RequestBody TextVO textVO) throws Exception {
        Gson gson = new Gson();
        JsonObject response = new JsonObject();

        try {
            int result = TextService.textUpdate(textVO);
            if (result > 0) {
                response.addProperty("status", "success");
                response.addProperty("message", "지문이 수정되었습니다.");
                return gson.toJson(response);
            } else {
                response.addProperty("message", "수정 실패");
                return gson.toJson(response);
            }
        } catch (Exception e) {
            response.addProperty("status", "error");
            response.addProperty("message", e.getMessage());
            return gson.toJson(response);
        }
    }


    /**
     * 지문 삭제
     */
    @PostMapping(value = "/textDelete.json")
    @Operation(summary = "지문 삭제")
    public String textDelete(@RequestBody Map<String, String> request) throws Exception {
        Gson gson = new Gson();
        JsonObject response = new JsonObject();

        String textId = request.get("textId");
        int result = TextService.textDelete(textId);
        try {
            if (result > 0) {
                response.addProperty("status", "success");
                response.addProperty("message", "사용자가 삭제되었습니다.");
                return gson.toJson(response);
            } else {
                response.addProperty("message", "삭제 실패");
                return gson.toJson(response);
            }
        } catch (Exception e) {
            response.addProperty("status", "error");
            response.addProperty("message", e.getMessage());
            return gson.toJson(response);
        }
    }


    /**
     * 지문 검색
     */
    @PostMapping("/textSearch.json")
    @Operation(summary = "지문 검색")
    public HashMap<String, Object> searchText(@RequestBody HashMap<String, Object> params) throws Exception {
        HashMap<String, Object> result = new HashMap<>();
        List<HashMap<String, Object>> textList = TextService.searchText(params);
        result.put("list", textList);
        return result;
    }

}

