package com.takensoft.ai_lms.lms.unit.web;

import com.takensoft.ai_lms.lms.unit.service.UnitService;
import com.takensoft.ai_lms.lms.unit.vo.UnitVO;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;

/**
 * @author  : 김건택
 * @since   : 2024.07.25
 *
 * 단원 관련 Controller 클래스
 */
@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping(value="/unit")
public class UnitController {

    private final UnitService unitService;

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 단원 목록 출력
     */
    @PostMapping(path = "/unitList.json")
    public ResponseEntity<?> unitList(@RequestBody UnitVO unitVO) throws Exception {
        List<UnitVO> result = unitService.unitList(unitVO);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 단원 등록
     */
    @PostMapping(path = "/insertUnit.json")
    public ResponseEntity<?> insertUnit(@RequestBody UnitVO unitVO) throws Exception {
        int result = unitService.insertUnit(unitVO);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 단원 수정
     */
    @PostMapping(path = "/updateUnit.json")
    public ResponseEntity<?> updateUnit(@RequestBody UnitVO unitVO) throws Exception {
        int result = unitService.updateUnit(unitVO);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 단원 삭제
     */
    @PostMapping(path = "/deleteUnit.json")
    public ResponseEntity<?> deleteUnit(@RequestBody UnitVO unitVO) throws Exception {
        int result = unitService.deleteUnit(unitVO);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }

    /**
     * @author  : 김건택
     * @since   : 2024.07.25
     *
     * 단원 상세 정보
     */
    @PostMapping(path = "/unitDetail.json")
    public ResponseEntity<?> unitDetail(@RequestBody UnitVO unitVO) throws Exception {
        List<HashMap<String, Object>> result = unitService.unitDetail(unitVO);
        return new ResponseEntity<>(result, HttpStatus.OK);
    }
}
