package com.takensoft.ai_lms.lms.user_unit.service.Impl;

import com.takensoft.ai_lms.lms.user_unit.dao.UserUnitDAO;
import com.takensoft.ai_lms.lms.user_unit.service.UserUnitService;
import com.takensoft.ai_lms.lms.user_unit.vo.UserUnitVO;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.sql.Timestamp;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.List;

/**
 * @author 권민수
 * @since 2024.08.02
 *
 * 사용자 학습 진행 정보 서비스 구현 클래스
 */

@Service
@RequiredArgsConstructor
public class UserUnitServiceImpl implements UserUnitService {

    private final UserUnitDAO userUnitDAO;

    @Override
    public List<UserUnitVO> getUserUnits() {
        return userUnitDAO.getUserUnits();
    }

    @Override
    public UserUnitVO getUserUnitById(UserUnitVO userUnit) {
        return userUnitDAO.getUserUnitById(userUnit);
    }

    @Override
    public void insertUserUnit(UserUnitVO userUnit) {
        userUnitDAO.insertUserUnit(userUnit);
    }

    @Override
    public void updateUserUnit(UserUnitVO userUnit) {
        // "yyyy-MM-dd HH:mm:ss.SSSSSS" 형식의 문자열을 Timestamp로 변환
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss.SSSSSS");
        LocalDateTime localDateTime = LocalDateTime.parse(userUnit.getCmptnTm(), formatter);
        Timestamp timestamp = Timestamp.valueOf(localDateTime);

        // DAO에 전달하기 전에 변환된 타임스탬프 설정
        userUnit.setCmptnTm(timestamp.toString());

        userUnitDAO.updateUserUnit(userUnit);
    }

    @Override
    public void deleteUserUnit(UserUnitVO userUnit) {
        userUnitDAO.deleteUserUnit(userUnit);
    }

}
