package com.takensoft.ai_lms.lms.user_unit.web;

import com.takensoft.ai_lms.lms.user_unit.service.UserUnitService;
import com.takensoft.ai_lms.lms.user_unit.vo.UserUnitVO;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * @author 권민수
 * @since 2024.08.02
 *
 * 사용자 학습 진행 정보 컨트롤러
 */

@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping("/userunit")
public class UserUnitController {

    private final UserUnitService userUnitService;

    // 유저 유닛 리스트 조회
    @PostMapping("/findAll.json")
    public List<UserUnitVO> getUserUnits() {
        return userUnitService.getUserUnits();
    }

    // 특정 유저 유닛 조회
    @PostMapping("/find.json")
    public UserUnitVO getUserUnitById(@RequestBody UserUnitVO userUnit) {
        return userUnitService.getUserUnitById(userUnit);
    }

    // 유저 유닛 생성
    @PostMapping("/insert.json")
    public void insertUserUnit(@RequestBody Map<String, String> req) {
        UserUnitVO userUnit = new UserUnitVO();
        userUnit.setUnitId(req.get("unitId"));
        userUnit.setStdId(req.get("stdId"));
        userUnit.setUserId(req.get("userId"));
        userUnit.setSclsId(req.get("sclsId"));
        userUnit.setCmptnYn(req.get("cmptnYn"));
        userUnit.setCmptnTm(req.get("cmptnTm"));
        userUnitService.insertUserUnit(userUnit);
    }

    // 유저 유닛 수정
    @PostMapping("/update.json")
    public void updateUserUnit(@RequestBody UserUnitVO userUnit) {
        userUnitService.updateUserUnit(userUnit);
    }

    // 유저 유닛 삭제
    @PostMapping("/delete.json")
    public void deleteUserUnit(@RequestBody UserUnitVO userUnit) {
        userUnitService.deleteUserUnit(userUnit);
    }

}
