package com.takensoft.ai_lms.lms.word_book.web;

import com.takensoft.ai_lms.lms.word_book.service.WordService;
import com.takensoft.ai_lms.lms.word_book.vo.WordVO;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * @author 권민수
 * @since 2024.07.30
 *
 * 단어 정보 관련 컨트롤러 클래스
 */

@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping("/word")
public class WordController {

    private final WordService wordService;

    // 단어장 아이디에 해당하는 단어 목록 조회
    @PostMapping("/getWordsByBookId.json")
    public List<WordVO> getWordsByBookId(@RequestBody Map<String, String> request) {
        return wordService.getWordsByBookId(request.get("wdBookId"));
    }

    // 단어 등록
    @PostMapping("/insert.json")
    public void insertWord(@RequestBody WordVO word) {
        wordService.insertWord(word);
    }

    // 단어 수정
    @PostMapping("/update.json")
    public void updateWord(@RequestBody WordVO word) {
        wordService.updateWord(word);
    }

    // 단어 삭제
    @PostMapping("/delete.json")
    public void deleteWord(@RequestBody WordVO word) {
        wordService.deleteWord(word.getWdId());
    }

}
